@@ -448,7 +448,7 @@ demarshal_value(CORBA_TypeCode tc, gconstpointer *val)
 	break;
     case CORBA_tk_objref:
 	alignval(val, ORBIT_ALIGNOF_CORBA_POINTER);
-	ret = pycorba_object_new(getval(val, CORBA_Object));
+	ret = pycorba_object_new_with_type(getval(val, CORBA_Object), tc);
 	advanceptr(val, sizeof(CORBA_Object));
 	break;
     case CORBA_tk_struct:
