@@ -616,8 +616,10 @@ pycorba_bound_method_async_call(PyCORBA_BoundMethod *self, PyObject *args, PyObj
     Py_INCREF(self->meth_self);
     PyList_SET_ITEM(selfarg, 0, self->meth_self);
     tmp = PySequence_Concat(selfarg, py_args);
-    if (!tmp)
+    if (!tmp) {
         PyErr_Print();
+        goto error;
+    }
     Py_DECREF(selfarg);
     args = PySequence_Tuple(tmp);
     Py_DECREF(tmp);
