@@ -21,6 +21,7 @@
 #  include <config.h>
 #endif
 
+#define PY_SIZE_T_CLEAN
 #include "pyorbit-private.h"
 #include <orbit/poa/poa-types.h>
 
@@ -162,15 +163,17 @@ pyorbit_poa_activate_object_with_id(PyCORBA_Object *self, PyObject *args)
     PyPortableServer_Servant *pyservant;
     PortableServer_ServantBase *servant;
     PortableServer_ObjectId *id;
+    Py_ssize_t id_length;
 
     id = (PortableServer_ObjectId *)CORBA_sequence_CORBA_octet__alloc();
     id->_release = CORBA_FALSE;
     if (!PyArg_ParseTuple(args, "s#O!:POA.activate_object_with_id",
-			  &id->_buffer, &id->_length,
+			  &id->_buffer, &id_length,
 			  &PyPortableServer_Servant_Type, &pyservant)) {
 	CORBA_free(id);
 	return NULL;
     }
+    id->_length = id_length;
     id->_length++; /* account for nul termination */
     servant = PYSERVANT_TO_SERVANT(pyservant);
 
@@ -190,14 +193,15 @@ pyorbit_poa_deactivate_object(PyCORBA_Object *self, PyObject *args)
 {
     CORBA_Environment ev;
     PortableServer_ObjectId *id;
-
+    Py_ssize_t id_length;
     id = (PortableServer_ObjectId *)CORBA_sequence_CORBA_octet__alloc();
     id->_release = CORBA_FALSE;
     if (!PyArg_ParseTuple(args, "s#:POA.deactivate_object",
-			  &id->_buffer, &id->_length)) {
+			  &id->_buffer, &id_length)) {
 	CORBA_free(id);
 	return NULL;
     }
+    id->_length = id_length;
     id->_length++; /* account for nul termination */
 
     CORBA_exception_init(&ev);
